==> apache-cassandra-4.0.19-src.tar.gz: apache-cassandra-4.0.19-src/test/unit/org/apache/cassandra/io/sstable/format/VersionAndTypeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.io.sstable.format;

import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThatThrownBy;
import static junit.framework.Assert.assertEquals;

public class VersionAndTypeTest
{
    @Test
    public void testValidInput()
    {
        assertEquals(VersionAndType.fromString("big-bc").toString(), "big-bc");
    }

    @Test
    public void testInvalidInputs()
    {
        assertThatThrownBy(() -> VersionAndType.fromString(" ")).isInstanceOf(IllegalArgumentException.class)
                                                                .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc-")).isInstanceOf(IllegalArgumentException.class)
                                                                   .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc-d")).isInstanceOf(IllegalArgumentException.class)
                                                                    .hasMessageContaining("No Type constant mcc");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc-d-")).isInstanceOf(IllegalArgumentException.class)
                                                                     .hasMessageContaining("No Type constant mcc");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc")).isInstanceOf(IllegalArgumentException.class)
                                                                  .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("-")).isInstanceOf(IllegalArgumentException.class)
                                                                .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("--")).isInstanceOf(IllegalArgumentException.class)
                                                                 .hasMessageContaining("should be of the form 'big-bc'");
    }
}

==> apache-cassandra-4.1.10-src.tar.gz: apache-cassandra-4.1.10-src/test/unit/org/apache/cassandra/io/sstable/format/VersionAndTypeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.io.sstable.format;

import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThatThrownBy;
import static org.junit.Assert.assertEquals;

public class VersionAndTypeTest
{
    @Test
    public void testValidInput()
    {
        assertEquals(VersionAndType.fromString("big-bc").toString(), "big-bc");
    }

    @Test
    public void testInvalidInputs()
    {
        assertThatThrownBy(() -> VersionAndType.fromString(" ")).isInstanceOf(IllegalArgumentException.class)
                                                                .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc-")).isInstanceOf(IllegalArgumentException.class)
                                                                   .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc-d")).isInstanceOf(IllegalArgumentException.class)
                                                                    .hasMessageContaining("No Type constant mcc");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc-d-")).isInstanceOf(IllegalArgumentException.class)
                                                                     .hasMessageContaining("No Type constant mcc");
        assertThatThrownBy(() -> VersionAndType.fromString("mcc")).isInstanceOf(IllegalArgumentException.class)
                                                                  .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("-")).isInstanceOf(IllegalArgumentException.class)
                                                                .hasMessageContaining("should be of the form 'big-bc'");
        assertThatThrownBy(() -> VersionAndType.fromString("--")).isInstanceOf(IllegalArgumentException.class)
                                                                 .hasMessageContaining("should be of the form 'big-bc'");
    }
}
